@@ -1,6 +1,8 @@
 from pathlib import Path
 from time import sleep
 import os
+import pathlib
+import shutil
 
 from disco.models import ClusterDetails
 from disco import Job
@@ -15,6 +17,7 @@ from click.testing import CliRunner
 from disco_cli import cli, setup_cli
 from .cli_test_utils import output_message_includes
 from tests.base_test import BaseTest
+from cli.job_commands import get_file_list
 
 
 class TestJobCommands(BaseTest):
@@ -1115,3 +1118,143 @@ class TestJobCommands(BaseTest):
         assert result.output == 'Results downloaded successfully\n'
         get_results_mock.assert_called()
         makedirs_mock.assert_called()
+
+    def test_get_files_list_of_files(self):
+        runner = CliRunner()
+        with runner.isolated_filesystem():
+            with open('input_file.txt', 'w') as f1:
+                f1.write("print('hi!')")
+                result = get_file_list(f1.name)
+                assert len(result) == 1
+                assert result[0] == Path(f1.name)
+
+                with open('input_file1.txt', 'w') as f2:
+                    file_list_string = f1.name + "," + f2.name
+                    result = get_file_list(file_list_string)
+                    assert len(result) == 2
+                    assert Path(f1.name) in result
+                    assert Path(f2.name) in result
+
+                    with open('input_file2.py', 'w') as f3:
+                        with open('temp.txt', 'w') as f4:
+                            result = get_file_list("input*")
+                            assert len(result) == 3
+                            assert Path(f1.name) in result
+                            assert Path(f2.name) in result
+                            assert Path(f3.name) in result
+
+                            result = get_file_list('input*.txt')
+                            assert len(result) == 2
+                            assert Path(f1.name) in result
+                            assert Path(f2.name) in result
+
+    def test_get_file_list_from_tree_get_directory(self):
+        try:
+            dir, sub_dir, dir_files_list, sub_dir_files_list = self._create_files_tree()
+            result = get_file_list(str(dir))
+            assert len(result) == 10
+            assert dir_files_list[0] in result
+            assert dir_files_list[1] in result
+            assert sub_dir_files_list[0] in result
+            assert sub_dir_files_list[1] in result
+            assert sub_dir not in result
+        finally:
+            if Path(dir).exists():
+                shutil.rmtree(dir)
+
+    def test_get_file_list_from_tree_get_file(self):
+        try:
+            dir, sub_dir, dir_files_list, sub_dir_files_list = self._create_files_tree()
+            result = get_file_list(str(os.path.join(dir, dir_files_list[0])))
+            assert len(result) == 1
+            assert dir_files_list[0] in result
+        finally:
+            if Path(dir).exists():
+                shutil.rmtree(dir)
+
+    def test_get_file_list_from_tree_get_directory_using_wildcards(self):
+        try:
+            dir, sub_dir, dir_files_list, sub_dir_files_list = self._create_files_tree()
+            result = get_file_list(str(dir) + '/*')
+            assert len(result) == 10
+            assert dir_files_list[3] in result
+            assert dir_files_list[4] in result
+            assert sub_dir_files_list[3] in result
+            assert sub_dir_files_list[4] in result
+            assert sub_dir not in result
+        finally:
+            if Path(dir).exists():
+                shutil.rmtree(dir)
+
+    def test_get_file_list_from_tree_get_file_with_wildcards(self):
+        try:
+            dir, sub_dir, dir_files_list, sub_dir_files_list = self._create_files_tree()
+            file = open(os.path.join(dir, f'test.txt'), 'w')
+            dir_files_list.append(Path(file.name))
+
+            result = get_file_list(str(dir) + '/file*')
+            assert len(result) == 10
+            assert dir_files_list[3] in result
+            assert dir_files_list[4] in result
+            assert sub_dir_files_list[3] in result
+            assert sub_dir_files_list[4] in result
+            assert sub_dir not in result
+
+            result = get_file_list(str(dir) + '/file[0-5]*.*')
+            assert len(result) == 6
+            assert dir_files_list[0] in result
+            assert dir_files_list[1] in result
+            assert sub_dir_files_list[0] in result
+            assert sub_dir not in result
+        finally:
+            if Path(dir).exists():
+                shutil.rmtree(dir)
+
+    def test_get_file_list_from_tree_get_current_directory_using_wildcards(self):
+        try:
+            dir, sub_dir, dir_files_list, sub_dir_files_list = self._create_files_tree()
+            result = get_file_list(dir.name + '/*')
+            assert len(result) == 10
+            assert dir_files_list[0].name in str(result)
+            assert dir_files_list[1].name in str(result)
+            assert sub_dir_files_list[0].name in str(result)
+            assert sub_dir_files_list[1].name in str(result)
+            assert sub_dir not in result
+        finally:
+            if Path(dir).exists():
+                shutil.rmtree(dir)
+
+    def test_get_file_list_from_tree_get_directories_no_duplications(self):
+        try:
+            dir, sub_dir, dir_files_list, sub_dir_files_list = self._create_files_tree()
+            result = get_file_list(f"{str(dir)}, {str(sub_dir)},")
+            assert len(result) == 10
+            assert dir_files_list[0] in result
+            assert dir_files_list[4] in result
+            assert sub_dir_files_list[0] in result
+            assert sub_dir_files_list[4] in result
+            assert sub_dir not in result
+        finally:
+            if Path(dir).exists():
+                shutil.rmtree(dir)
+
+    def _create_files_tree(self):
+        try:
+            temp_dir = pathlib.Path.cwd() / self.random_str('temp_dir')
+            temp_dir.mkdir()
+            temp_sub_dir = pathlib.Path.cwd() / temp_dir / self.random_str('sub_dir')
+            temp_sub_dir.mkdir()
+            temp_dir_files_list = list()
+            for x in range(5):
+                file = open(os.path.join(temp_dir, f'file{x}.txt'), 'w')
+                temp_dir_files_list.append(Path(file.name))
+            temp_sub_dir_files_list = list()
+            for x in range(5,10):
+                file = open(os.path.join(temp_sub_dir, f'file{x}.txt'), 'w')
+                temp_sub_dir_files_list.append(Path(file.name))
+            return temp_dir, temp_sub_dir, temp_dir_files_list, temp_sub_dir_files_list
+        except Exception:
+            if Path(temp_dir).exists():
+                shutil.rmtree(temp_dir)
+
+
